import { SvelteComponentTyped } from "svelte";
import type { LinkType } from '../types';
declare const __propDef: {
    props: {
        [x: string]: any;
        items?: (LinkType & {
            [propName: string]: any;
        })[] | undefined;
        full?: boolean | undefined;
        open?: boolean | undefined;
        ulClass?: string | undefined;
    };
    events: {
        show: CustomEvent<any>;
    } & {
        [evt: string]: CustomEvent<any>;
    };
    slots: {
        default: {
            item: LinkType & {
                [propName: string]: any;
            };
        };
        extra: {};
    };
};
export type MegaMenuProps = typeof __propDef.props;
export type MegaMenuEvents = typeof __propDef.events;
export type MegaMenuSlots = typeof __propDef.slots;
/**
 * ## Feature
 * [Go to Mega Menu](https://flowbite-svelte.com/docs/components/mega-menu)
 * - Setup
 * - Default mega menu
 * - Mega menu with icons
 * - Full width dropdown
 * - Full width with CTA
 * - Full width with image
 * ## Props
 * @prop items: LinkTypeLike[] = [];
 * @prop full: boolean = false;
 * @prop open: boolean = false;
 * ## Example
 * ```
 * <script>
 *   import { Navbar, NavBrand, NavHamburger, NavUl, NavLi, Chevron, MegaMenu } from 'flowbite-svelte'
 *   let menu = [
 *     {name: 'About us', href: '/about'},
 *     {name: 'Blog', href: '/blog'},
 *     {name: 'Contact us', href: '/contact'},
 *     {name: 'Library', href: '/library'},
 *     {name: 'Newsletter', href: '/news'},
 *     {name: 'Support Center', href: '/support'},
 *     {name: 'Resources', href: '/resource'},
 *     {name: 'Playground', href: '/play'},
 *     {name: 'Terms', href: '/terms'},
 *     {name: 'Pro Version', href: '/pro'},
 *     {name: 'License', href: '/license'},
 *   ];
 * </script>
 *
 * <Navbar let:hidden let:toggle>
 *   <NavBrand href="/">
 *     <img src="/images/flowbite-svelte-icon-logo.svg" class="mr-3 h-6 sm:h-9" alt="Flowbite Logo"/>
 *     <span class="self-center whitespace-nowrap text-xl font-semibold dark:text-white">Flowbite</span>
 *   </NavBrand>
 *   <NavHamburger on:click={toggle} />
 *   <NavUl {hidden}>
 *     <NavLi href="/">Home</NavLi>
 *     <NavLi><Chevron aligned>Mega menu</Chevron></NavLi>
 *     <MegaMenu items={menu} let:item>
 *       <a href={item.href} class="hover:text-blue-600 dark:hover:text-blue-500">{item.name}</a>
 *     </MegaMenu>
 *     <NavLi href="/services">Services</NavLi>
 *     <NavLi href="/services">Products</NavLi>
 *     <NavLi href="/services">Contact</NavLi>
 *   </NavUl>
 * </Navbar>
 * ```
 */
export default class MegaMenu extends SvelteComponentTyped<MegaMenuProps, MegaMenuEvents, MegaMenuSlots> {
}
export {};
//# sourceMappingURL=MegaMenu.svelte.d.ts.map